@@ -1,8 +1,8 @@
 from .base import PrintFX
 
 __copyright__ = "Copyright 2025 by kaedeek"
-__version__ = "1.0.4"
+__version__ = "1.1.0"
 __author__ = "kaedeek"
 __url__ = "https://github.com/kaedeek"
 
-__all__ = ["printfxpy"]
\ No newline at end of file
+__all__ = ["PrintFX"]
\ No newline at end of file
